@@ -1,14 +1,11 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: about.c 1083 2005-06-05 09:56:01Z kiza $
+ * $Id: about.c 1177 2008-02-17 09:20:34Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
  *
  * about.c
  *
- * Please read the file README.patching before changing any code in this file!
- *
- *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
  * published by the Free Software Foundation.
@@ -692,7 +689,8 @@ void UIAbout (void) {
 		mvaddstr (20, COLS/2-31, "Oliver Feiler, Frank van der Loo, Pascal Varet, Simon Isakovic,");
 		mvaddstr (21, COLS/2-32, "Fernando J. Pereda, Marco Cova, Cheng-Lung Sung, Dmitry Petukhov");
 		mvaddstr (22, COLS/2-26, "Douglas Campos, Ray Iwata, Piotr Ozarowski, Yang Huan");
-
+		mvaddstr (23, COLS/2-15, "Ihar Hrachyshka, Mats Berglund");
+		
 		refresh();
 		getch();
 	}
