@@ -31,7 +31,7 @@
 #include <errno.h>
 #include <libxml/HTMLparser.h>
 #include <langinfo.h>
-/*#include <md5.h>*/
+#include <openssl/evp.h>
 
 #include "os-support.h"
 
@@ -51,7 +51,6 @@
 #include "ui-support.h"
 #include "setup.h"
 #include "digcalc.h"
-#include "md5.h"
 #include "io-internal.h"
 
 extern struct entity *first_entity;
@@ -619,20 +618,26 @@ char * Hashify (const char * url) {
 
 char * genItemHash (char ** hashitems, int items) {
 	int i;
-	unsigned char MD5Digest[16];
-	struct MD5Context MD5Ctx;
-	HASHHEX HexDigest;
-	
-	MD5Init (&MD5Ctx);
+	EVP_MD_CTX mdctx;
+	unsigned char md_value[EVP_MAX_MD_SIZE];
+	unsigned int md_len;
+	char md5_hex[33];
+
+	EVP_DigestInit(&mdctx, EVP_md5());
 	
 	for (i = 0; i < items; i++) {
 		if (hashitems[i] != NULL)
-			MD5Update (&MD5Ctx, (unsigned char *)hashitems[i], strlen(hashitems[i]));
+			EVP_DigestUpdate(&mdctx, hashitems[i], (size_t) strlen(hashitems[i]));
 	}
-	MD5Final (MD5Digest, &MD5Ctx);
-	CvtHex (MD5Digest, HexDigest);
 	
-	return strdup(HexDigest);
+	EVP_DigestFinal_ex(&mdctx, md_value, &md_len);
+	EVP_MD_CTX_cleanup(&mdctx);
+	
+	for (i = 0; i < md_len; i++) {
+		sprintf(&md5_hex[2*i], "%02x", md_value[i]);
+	}
+	
+	return strdup(md5_hex);
 }
 
 /* Date conversion */
