@@ -468,7 +468,7 @@ void UIDisplayFeedHelp (void) {
 	centerx = COLS / 2;
 	centery = LINES / 2;
 	
-	UISupportDrawBox ((COLS/2)-20, (LINES/2)-6, (COLS/2)+24, (LINES/2)+6);
+	UISupportDrawBox ((COLS/2)-20, (LINES/2)-6, (COLS/2)+24, (LINES/2)+7);
 	
 	attron (WA_REVERSE);
 	/* Keys */
@@ -476,25 +476,27 @@ void UIDisplayFeedHelp (void) {
 	mvprintw (centery-4, centerx-offset, _("%c, down:"), keybindings.next);
 	mvaddstr (centery-3, centerx-offset, _("enter:"));
 	mvprintw (centery-2, centerx-offset, "%c:", keybindings.reload);
-	mvprintw (centery-1, centerx-offset, "%c:", keybindings.urljump);
-	mvprintw (centery,   centerx-offset, "%c:", keybindings.urljump2);
-	mvprintw (centery+1, centerx-offset, "%c:", keybindings.markread);
-	mvprintw (centery+2, centerx-offset, "%c:", keybindings.markunread);
-	mvprintw (centery+3, centerx-offset, "%c:", keybindings.feedinfo);
-	mvaddstr (centery+4, centerx-offset, _("tab:"));
-	mvprintw (centery+5, centerx-offset, "%c:", keybindings.prevmenu);
+	mvprintw (centery-1, centerx-offset, "%c:", keybindings.forcereload);
+	mvprintw (centery,   centerx-offset, "%c:", keybindings.urljump);
+	mvprintw (centery+1, centerx-offset, "%c:", keybindings.urljump2);
+	mvprintw (centery+2, centerx-offset, "%c:", keybindings.markread);
+	mvprintw (centery+3, centerx-offset, "%c:", keybindings.markunread);
+	mvprintw (centery+4, centerx-offset, "%c:", keybindings.feedinfo);
+	mvaddstr (centery+5, centerx-offset, _("tab:"));
+	mvprintw (centery+6, centerx-offset, "%c:", keybindings.prevmenu);
 	/* Descriptions */
 	mvprintw (centery-5, centerx-offsetstr, _("Previous item"));	
 	mvprintw (centery-4, centerx-offsetstr, _("Next item"));
 	mvaddstr (centery-3, centerx-offsetstr, _("View item"));
 	mvprintw (centery-2, centerx-offsetstr, _("Reload this feed"));
-	mvprintw (centery-1, centerx-offsetstr, _("Open homepage"));
-	mvprintw (centery,   centerx-offsetstr, _("Open link"));
-	mvprintw (centery+1, centerx-offsetstr, _("Mark all read"));
-	mvprintw (centery+2, centerx-offsetstr, _("Toggle item read status"));
-	mvprintw (centery+3, centerx-offsetstr, _("Show feed info..."));
-	mvaddstr (centery+4, centerx-offsetstr, _("Type Ahead Find"));
-	mvprintw (centery+5, centerx-offsetstr, _("Return to main menu"));
+	mvprintw (centery-1, centerx-offsetstr, _("Force reload this feed"));
+	mvprintw (centery,   centerx-offsetstr, _("Open homepage"));
+	mvprintw (centery+1, centerx-offsetstr, _("Open link"));
+	mvprintw (centery+2, centerx-offsetstr, _("Mark all read"));
+	mvprintw (centery+3, centerx-offsetstr, _("Toggle item read status"));
+	mvprintw (centery+4, centerx-offsetstr, _("Show feed info..."));
+	mvaddstr (centery+5, centerx-offsetstr, _("Type Ahead Find"));
+	mvprintw (centery+6, centerx-offsetstr, _("Return to main menu"));
 	attroff (WA_REVERSE);
 
 	UIStatus (_("Press the any(tm) key to exit help screen."), 0, 0);
