@@ -401,11 +401,12 @@ void WriteCache (void) {
 	/* Make a backup of urls. This approach is really broken! */
 	if ((stat (file, &filetest)) != -1) {
 		if ((filetest.st_mode & S_IFREG) == S_IFREG) {
-			snprintf (syscall, sizeof(file), "cp -f %s/.snownews/urls %s/.snownews/urls.bak", getenv("HOME"), getenv("HOME"));
+			snprintf (syscall, sizeof(file), "mv -f %s/.snownews/urls %s/.snownews/urls.bak", getenv("HOME"), getenv("HOME"));
 			system (syscall);
 		}
 	}
 	
+	snprintf (file, sizeof(file), "%s/.snownews/urls.new", getenv("HOME"));
 	configfile = fopen (file, "w+");
 	if (configfile == NULL) {
 		MainQuit (_("Save settings (urls)"), strerror(errno));
@@ -549,6 +550,9 @@ void WriteCache (void) {
 	}
 	fclose (configfile);
 	
+	snprintf (syscall, sizeof(file), "mv -f %s/.snownews/urls.new %s/.snownews/urls", getenv("HOME"), getenv("HOME"));
+	system (syscall);
+	
 	return;
 }
 
@@ -558,8 +562,18 @@ void printlog (struct feed * feed, const char * text) {
 	
 	t = time(NULL);
 	timestring = ctime(&t);
-	
 	timestring[strlen(timestring)-1] = 0;
 	
 	fprintf (stderr, "%s: (%s) %s\n", timestring, feed->feedurl, text);
 }
+
+void printlogSimple (const char * text) {
+	char *timestring;
+	time_t t;
+	
+	t = time(NULL);
+	timestring = ctime(&t);
+	timestring[strlen(timestring)-1] = 0;
+	
+	fprintf (stderr, "%s: %s\n", timestring, text);
+}
