@@ -51,11 +51,13 @@ static int last_signal = 0;
 
 int cursor_always_visible = 0;
 
+char *forced_target_charset = NULL;
+
 void modifyPIDFile (int action) {
 	char pid_path[512];
 	FILE *file;
 	
-	snprintf(pid_path, sizeof(pid_path), "%s/.snownews/pid", getenv("HOME"));	
+	snprintf(pid_path, sizeof(pid_path), "%s/.snownews/pid", getenv("HOME"));
 	if (action == pid_file_create) {
 		file = fopen(pid_path, "w");
 		if (file == NULL) {
@@ -69,6 +71,41 @@ void modifyPIDFile (int action) {
 	}
 }
 
+void checkPIDFile (void) {
+	char pid_path[256];
+	char buf[16];
+	char *choice;
+	int pid;
+	FILE *pidfile;
+	struct stat filetest;
+	
+	snprintf(pid_path, sizeof(pid_path), "%s/.snownews/pid", getenv("HOME"));
+	
+	if (stat (pid_path, &filetest) == 0) {
+		pidfile = fopen(pid_path, "r");
+		if (pidfile) {
+			fgets(buf, sizeof(buf), pidfile);
+			pid = atoi(buf);
+			
+			if (kill(pid, 0) == 0) {
+				printf("Snownews seems to be already running with process ID %d.\n", pid);
+				printf("A pid file exists at \"%s\".\n", pid_path);
+				exit(2);
+			} else {
+				printf("A pid file exists at \"%s\",\nbut Snownews doesn't seem to be running. Delete that file and start it again.\n", pid_path);
+				printf("Continue anyway? (y/n) ");
+				choice = fgets(buf, 2, stdin);
+				if (choice[0] == 'y') {
+					modifyPIDFile(pid_file_delete);
+					return;
+				} else {
+					exit(2);
+				}
+			}
+		}
+	}
+}
+
 /* Deinit ncurses and quit. */
 void MainQuit (const char * func, const char * error) {
 	if (error == NULL) {
@@ -80,7 +117,7 @@ void MainQuit (const char * func, const char * error) {
 	endwin();		/* Make sure no ncurses function is called after this point! */
 	
 	modifyPIDFile(pid_file_delete);
-
+	
 	if (last_signal)
 		printf ("Exiting via signal %d.\n", last_signal);
 	
@@ -132,13 +169,14 @@ void sigChildHandler (int sig) {
 void printHelp (void) {
 	printf (_("Snownews version %s\n\n"), VERSION);
 	printf (_("usage: snownews [-huV] [--help|--update|--version]\n\n"));
+	printf (_("\t--charset|-l\tForce using this charset.\n"));
 	printf (_("\t--cursor-on|-c\tForce cursor always visible.\n"));
 	printf (_("\t--help|-h\tPrint this help message.\n"));
 	printf (_("\t--update|-u\tAutomatically update every feed.\n"));
 	printf (_("\t--version|-V\tPrint version number and exit.\n"));
 }
 void badOption (const char * arg) {
-	printf ("Option %s requires an argument.\n", arg);
+	printf (_("Option %s requires an argument.\n"), arg);
 }
 
 int main (int argc, char *argv[]) {
@@ -159,7 +197,6 @@ int main (int argc, char *argv[]) {
 #endif
 	
 	if (argc > 1) {
-//		printf ("=%d\n", argc);	
 		i = 1;
 		while (i < argc) {
 			arg = argv[i];
@@ -174,16 +211,16 @@ int main (int argc, char *argv[]) {
 				cursor_always_visible = 1;
 				i++;
 				continue;
-			} else if (strcmp(arg, "--foo") == 0) {
-				i++;
-				if (i < argc) {
-					foo = strdup(argv[i]);
-					i++;
-					continue;
+			} else if (strcmp(arg, "-l") == 0 || strcmp(arg, "--charset") == 0) {
+				foo = argv[i+1];
+				if (foo) {
+					forced_target_charset = foo;
+					i += 2;
 				} else {
 					badOption(arg);
 					exit(1);
 				}
+				continue;
 			} else if (strcmp(arg, "-h") == 0 || strcmp(arg, "--help") == 0) {
 				printHelp();
 				return 0;
@@ -195,7 +232,11 @@ int main (int argc, char *argv[]) {
 		}
 	}
 	
-	/* Get fragged gracefully. */
+	checkPIDFile();
+	
+	/* Create PID file. */
+	modifyPIDFile(pid_file_create);
+
 	signal (SIGHUP, MainSignalHandler);
 	signal (SIGINT, MainSignalHandler);
 	signal (SIGTERM, MainSignalHandler);
@@ -203,7 +244,6 @@ int main (int argc, char *argv[]) {
 	/* Un-broken pipify */
 	signal (SIGPIPE, SIG_IGN);
 	
-	/* Call the reaper */
 	signal (SIGCHLD, sigChildHandler);
 	
 #ifdef SIGWINCH
@@ -218,10 +258,7 @@ int main (int argc, char *argv[]) {
 	
 	/* Check if configfiles exist and create/read them. */
 	numfeeds = Config();
-	
-	/* Create PID file. */
-	modifyPIDFile(pid_file_create);
-		
+			
 	LoadAllFeeds (numfeeds);
 
 	if (autoupdate)
