@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: main.h 500 2004-12-08 14:02:44Z kiza $
+ * $Id: main.h 1159 2005-09-13 19:51:13Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -26,6 +26,6 @@
 
 #include "config.h"
 
-void MainQuit(char * func, char * error);
+void MainQuit(const char * func, const char * error);
 
 #endif
