@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: net-support.h 1057 2005-04-27 18:00:53Z kiza $
+ * $Id: net-support.h 1159 2005-09-13 19:51:13Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -24,7 +24,7 @@
 #ifndef NET_SUPPORT_H
 #define NET_SUPPORT_H
 
-int NetSupportAuth (struct feed * cur_ptr, char * authdata, char * url, char * netbuf);
+int NetSupportAuth (struct feed * cur_ptr, const char * authdata, char * url, const char * netbuf);
 int checkValidHTTPHeader (const unsigned char * header, int size);
 int checkValidHTTPURL (const unsigned char * url);
 
