@@ -1,14 +1,11 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: ui-support.c 1083 2005-06-05 09:56:01Z kiza $
+ * $Id: ui-support.c 1160 2005-09-15 23:12:27Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
  *
  * ui-support.c
  *
- * Please read the file README.patching before changing any code in this file!
- *
- *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
  * published by the Free Software Foundation.
@@ -38,6 +35,7 @@
 
 extern struct color color;
 extern char *browser;
+extern int cursor_always_visible;
 
 /* Init the ncurses library. */
 void InitCurses (void) {
@@ -48,12 +46,13 @@ void InitCurses (void) {
 	cbreak();				/* No buffering. */
 	noecho();				/* Do not echo typed chars onto the screen. */
 	clear();
-	curs_set(0);			/* Hide cursor. */
+	if (!cursor_always_visible)
+		curs_set(0);			/* Hide cursor. */
 	refresh();
 }
 
 /* Print text in statusbar. */
-void UIStatus (char * text, int delay, int warning) {
+void UIStatus (const char * text, int delay, int warning) {
 	if (warning)
 		attron (COLOR_PAIR(10));
 	clearLine (LINES-1, INVERSE);
@@ -147,7 +146,7 @@ void SwapPointers (struct feed * one, struct feed * two) {
 }
 
 /* Ignore "A", "The", etc. prefixes when sorting feeds. */
-char * SnowSortIgnore (char * title) {
+const char * SnowSortIgnore (const char * title) {
 	if (strncasecmp (title, "a ", 2) == 0)
 		return title+2;
 	else if (strncasecmp (title, "the ", 4) == 0)
@@ -161,7 +160,7 @@ char * SnowSortIgnore (char * title) {
 void SnowSort (void) {
 	int elements = 0;
 	int i;
-	char *one, *two;
+	const char *one, *two;
 	struct feed * cur_ptr;
 	
 	/* If there is no element do not run sort or it'll crash! */
@@ -191,14 +190,33 @@ void UISupportDrawBox (int x1, int y1, int x2, int y2) {
 	attron (WA_REVERSE);
 	for (i = y1; i <= y2; i++) {
 		for (j = x1; j <= x2; j++) {
-				mvaddch (i, j, ' ');
+/* Pretty borders. Well, they just sucked. ;)
+			if (i == y1) {
+				if (j == x1)
+					mvaddch (i, j, ACS_ULCORNER);
+				else if (j == x2)
+					mvaddch (i, j, ACS_URCORNER);
+				else
+					mvaddch (i, j, ACS_HLINE);
+			} else if (i == y2) {
+				if (j == x1)
+					mvaddch (i, j, ACS_LLCORNER);
+				else if (j == x2)
+					mvaddch (i, j, ACS_LRCORNER);
+				else
+					mvaddch (i, j, ACS_HLINE);
+			} else if (j == x1 || j == x2) {
+				mvaddch (i, j, ACS_VLINE);
+			} else
+*/
+			mvaddch (i, j, ' ');
 		}	
 	}
 	attroff (WA_REVERSE);
 }
 
 /* Draw main program header. */
-void UISupportDrawHeader (char * headerstring) {
+void UISupportDrawHeader (const char * headerstring) {
 	clearLine (0, INVERSE);
 	
 	attron (WA_REVERSE);
@@ -215,7 +233,7 @@ void UISupportDrawHeader (char * headerstring) {
 
 /* Take a URL and execute in default browser.
    Apply all security restrictions before running system()! */
-void UISupportURLJump (char * url) {
+void UISupportURLJump (const char * url) {
 	int len;
 	char *tmp;
 	char *escapetext = NULL;
@@ -268,7 +286,8 @@ void UISupportURLJump (char * url) {
 	InitCurses();
 
 	/* Hide cursor again. */
-	curs_set(0);
+	if (!cursor_always_visible)
+		curs_set(0);
 
 	free (tmp);
 	free (syscall);
